==> request-tracker4_4.4.7+dfsg.orig-third-party-source.tar.gz: rt-4.4.7/devel/third-party/ckeditor-src/plugins/link/lang/fr-ca.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'fr-ca', {
	acccessKey: 'Touche d\'accessibilité',
	advanced: 'Avancé',
	advisoryContentType: 'Type de contenu',
	advisoryTitle: 'Description',
	anchor: {
		toolbar: 'Ancre',
		menu: 'Modifier l\'ancre',
		title: 'Propriétés de l\'ancre',
		name: 'Nom de l\'ancre',
		errorName: 'Veuillez saisir le nom de l\'ancre',
		remove: 'Supprimer l\'ancre'
	},
	anchorId: 'Par ID',
	anchorName: 'Par nom',
	charset: 'Encodage de la cible',
	cssClasses: 'Classes CSS',
	emailAddress: 'Courriel',
	emailBody: 'Corps du message',
	emailSubject: 'Objet du message',
	id: 'ID',
	info: 'Informations sur le lien',
	langCode: 'Code de langue',
	langDir: 'Sens d\'écriture',
	langDirLTR: 'De gauche à droite (LTR)',
	langDirRTL: 'De droite à gauche (RTL)',
	menu: 'Modifier le lien',
	name: 'Nom',
	noAnchors: '(Pas d\'ancre disponible dans le document)',
	noEmail: 'Veuillez saisir le courriel',
	noUrl: 'Veuillez saisir l\'URL',
	other: '<autre>',
	popupDependent: 'Dépendante (Netscape)',
	popupFeatures: 'Caractéristiques de la fenêtre popup',
	popupFullScreen: 'Plein écran (IE)',
	popupLeft: 'Position de la gauche',
	popupLocationBar: 'Barre d\'adresse',
	popupMenuBar: 'Barre de menu',
	popupResizable: 'Redimensionnable',
	popupScrollBars: 'Barres de défilement',
	popupStatusBar: 'Barre d\'état',
	popupToolbar: 'Barre d\'outils',
	popupTop: 'Position à partir du haut',
	rel: 'Relation',
	selectAnchor: 'Sélectionner une ancre',
	styles: 'Style',
	tabIndex: 'Ordre de tabulation',
	target: 'Destination',
	targetFrame: '<Cadre>',
	targetFrameName: 'Nom du cadre de destination',
	targetPopup: '<fenêtre popup>',
	targetPopupName: 'Nom de la fenêtre popup',
	title: 'Lien',
	toAnchor: 'Ancre dans cette page',
	toEmail: 'Courriel',
	toUrl: 'URL',
	toolbar: 'Lien',
	type: 'Type de lien',
	unlink: 'Supprimer le lien',
	upload: 'Téléverser'
} );

==> request-tracker5_5.0.7+dfsg.orig-third-party-source.tar.gz: rt-5.0.7/devel/third-party/ckeditor-src/plugins/link/lang/fr-ca.js <==
﻿/*
Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'fr-ca', {
	acccessKey: 'Touche d\'accessibilité',
	advanced: 'Avancé',
	advisoryContentType: 'Type de contenu',
	advisoryTitle: 'Description',
	anchor: {
		toolbar: 'Ancre',
		menu: 'Modifier l\'ancre',
		title: 'Propriétés de l\'ancre',
		name: 'Nom de l\'ancre',
		errorName: 'Veuillez saisir le nom de l\'ancre',
		errorWhitespace: 'Anchor name cannot contain space characters', // MISSING
		remove: 'Supprimer l\'ancre'
	},
	anchorId: 'Par ID',
	anchorName: 'Par nom',
	charset: 'Encodage de la cible',
	cssClasses: 'Classes CSS',
	download: 'Force Download', // MISSING
	displayText: 'Afficher le texte',
	emailAddress: 'Courriel',
	emailBody: 'Corps du message',
	emailSubject: 'Objet du message',
	id: 'ID',
	info: 'Informations sur le lien',
	langCode: 'Code de langue',
	langDir: 'Sens d\'écriture',
	langDirLTR: 'De gauche à droite (LTR)',
	langDirRTL: 'De droite à gauche (RTL)',
	menu: 'Modifier le lien',
	name: 'Nom',
	noAnchors: '(Pas d\'ancre disponible dans le document)',
	noEmail: 'Veuillez saisir le courriel',
	noUrl: 'Veuillez saisir l\'URL',
	noTel: 'Please type the phone number', // MISSING
	other: '<autre>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Dépendante (Netscape)',
	popupFeatures: 'Caractéristiques de la fenêtre popup',
	popupFullScreen: 'Plein écran (IE)',
	popupLeft: 'Position de la gauche',
	popupLocationBar: 'Barre d\'adresse',
	popupMenuBar: 'Barre de menu',
	popupResizable: 'Redimensionnable',
	popupScrollBars: 'Barres de défilement',
	popupStatusBar: 'Barre d\'état',
	popupToolbar: 'Barre d\'outils',
	popupTop: 'Position à partir du haut',
	rel: 'Relation',
	selectAnchor: 'Sélectionner une ancre',
	styles: 'Style',
	tabIndex: 'Ordre de tabulation',
	target: 'Destination',
	targetFrame: '<Cadre>',
	targetFrameName: 'Nom du cadre de destination',
	targetPopup: '<fenêtre popup>',
	targetPopupName: 'Nom de la fenêtre popup',
	title: 'Lien',
	toAnchor: 'Ancre dans cette page',
	toEmail: 'Courriel',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Lien',
	type: 'Type de lien',
	unlink: 'Supprimer le lien',
	upload: 'Téléverser'
} );
